severity = brutal
verbose = 8
exclude = Documentation::RequirePODUseEncodingUTF8 Editor::RequireEmacsFileVariables Miscellanea::RequireRcsKeywords Modules::RequireExplicitInclusion Modules::RequireExplicitPackage Modules::RequirePerlVersion Tics::ProhibitLongLines CodeLayout::ProhibitHashBarewords

[Lax::RequireExplicitPackage::ExceptForPragmata]
allowed_pragmata = diagnostics feature perlversion strict warnings utf8 Modern::Perl

[CodeLayout::RequireTidyCode]
perltidyrc = xt/author/perltidy.rc

# since we're using Modern::Perl
[Compatibility::PerlMinimumVersionAndWhy]
above_version = 5.010
[Compatibility::PodMinimumVersion]
above_version = 5.010

[ControlStructures::ProhibitPostfixControls]
flowcontrol = carp cluck confess croak die exit goto warn exit

[Documentation::PodSpelling]
stop_words = Perldoc perldoc annonations PASSed prepended superclass FOREIGNBUILDARGS hashref accessor TreePath TreePathValue

[Documentation::RequirePodSections]
lib_sections = NAME | VERSION | SYNOPSIS | DESCRIPTION | SUPPORT | AUTHOR | COPYRIGHT AND LICENSE
script_sections = NAME | USAGE | DESCRIPTION | CONFIGURATION | SUPPORT | AUTHOR | COPYRIGHT AND LICENSE

[InputOutput::RequireCheckedSyscalls]
functions = :builtins
exclude_functions = print

[Subroutines::ProhibitCallsToUndeclaredSubs]
exempt_subs = Const::Fast::const Moose::after Moose::around Moose::before Moose::blessed Moose::extends Moose::has Moose::with Moose::Util::TypeConstraints::as Moose::Util::TypeConstraints::coerce Moose::Util::TypeConstraints::from Moose::Util::TypeConstraints::maybe_type Moose::Util::TypeConstraints::union Moose::Util::TypeConstraints::via Path::Class::dir Path::Class::file Try::Tiny::catch Try::Tiny::try

[Subroutines::ProhibitUnusedPrivateSubroutines]
private_name_regex = _(?!build_)\w+

[TestingAndDebugging::RequireUseStrict]
equivalent_modules = Modern::Perl

[TestingAndDebugging::RequireUseWarnings]
equivalent_modules = Modern::Perl
